@@ -432,7 +432,7 @@ class Molecule(Molecule_sts):
     current_vae_dim - current value of i * dimensionless_vibrational_energy(i) averaged over the vibrational spectrum
     """
     def __init__(self, name, vmodel='anharmonic'):
-        Molecule_sts.__init__(name, vmodel)
+        Molecule_sts.__init__(self, name, vmodel)
 
         self.current_T1 = 1.0
         self.current_Z_vibr = 0.0
